<?php

global $authenticate_text;
$authenticate_text = array (

'loginsuccessful'	=>	'Login succesvol.',
'loginfailed'		=>	'Login MISLUKT!',
'userandpass'		=>	'U hebt geen gebruikersnaam en wachtwoord getypt',
'youareloggedout'	=>	'U bent uitgelogd',
'waitwhiletransfer'	=>	'Wacht even alstublieft terwijl u doorverwezen wordt...',
'clicknowait'		=>	'Klik hier als u niet wenst te wachten',

// Added in 0.9.7
'accountdisabled'       =>      'Uw account is uitgeschakeld.  Neem contact op met een beheerder.',

);
?>
